==> haskell-fold-debounce-0.2.0.10-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fold-debounce.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fold-debounce
version:              0.2.0.10
visibility:           public
id:                   fold-debounce-0.2.0.10-EGMsPgGnCb4H7V8g3iUKhO
key:                  fold-debounce-0.2.0.10-EGMsPgGnCb4H7V8g3iUKhO
license:              BSD-3-Clause
maintainer:           Toshio Ito <debug.ito@gmail.com>
author:               Toshio Ito <debug.ito@gmail.com>
homepage:             https://github.com/debug-ito/fold-debounce
synopsis:             Fold multiple events that happen in a given period of time.
description:
    Fold multiple events that happen in a given period of time. See "Control.FoldDebounce".

category:             Control
abi:                  8bbce865c950c61cfc119318ef6dae16
exposed:              True
exposed-modules:      Control.FoldDebounce
import-dirs:          /usr/lib/ghc-9.0.2/site-local/fold-debounce-0.2.0.10
library-dirs:         /usr/lib/ghc-9.0.2/site-local/fold-debounce-0.2.0.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fold-debounce
hs-libraries:         HSfold-debounce-0.2.0.10-EGMsPgGnCb4H7V8g3iUKhO
depends:
    base-4.15.1.0 data-default-class-0.1.2.0-IxhEAzgy8931aXcEiJcyZO
    stm-2.5.0.0 stm-delay-0.1.1.1-6DJ9BCTtZCk3qd7rnEUrtM time-1.9.3

haddock-interfaces:
    /usr/share/doc/haskell-fold-debounce/html/fold-debounce.haddock

haddock-html:         /usr/share/doc/haskell-fold-debounce/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fold-debounce-0.2.0.10-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fold-debounce.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fold-debounce
version:              0.2.0.10
visibility:           public
id:                   fold-debounce-0.2.0.10-Dz8cZureRdUHLBFmfPaDsj
key:                  fold-debounce-0.2.0.10-Dz8cZureRdUHLBFmfPaDsj
license:              BSD-3-Clause
maintainer:           Toshio Ito <debug.ito@gmail.com>
author:               Toshio Ito <debug.ito@gmail.com>
homepage:             https://github.com/debug-ito/fold-debounce
synopsis:             Fold multiple events that happen in a given period of time.
description:
    Fold multiple events that happen in a given period of time. See "Control.FoldDebounce".

category:             Control
abi:                  e7a09002e12f391aa3425ac38d7d971d
exposed:              True
exposed-modules:      Control.FoldDebounce
import-dirs:          /usr/lib/ghc-9.0.2/site-local/fold-debounce-0.2.0.10
library-dirs:         /usr/lib/ghc-9.0.2/site-local/fold-debounce-0.2.0.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fold-debounce
hs-libraries:         HSfold-debounce-0.2.0.10-Dz8cZureRdUHLBFmfPaDsj
depends:
    base-4.15.1.0 data-default-class-0.1.2.0-IxhEAzgy8931aXcEiJcyZO
    stm-2.5.0.0 stm-delay-0.1.1.1-6DJ9BCTtZCk3qd7rnEUrtM time-1.9.3

haddock-interfaces:
    /usr/share/doc/haskell-fold-debounce/html/fold-debounce.haddock

haddock-html:         /usr/share/doc/haskell-fold-debounce/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
